@@ -34,6 +34,8 @@
 #include "as-provide.h"
 #include "as-release.h"
 #include "as-screenshot.h"
+#include "as-content-rating.h"
+#include "as-translation.h"
 
 G_BEGIN_DECLS
 
@@ -168,6 +170,66 @@ typedef enum {
 	AS_APP_SOURCE_KIND_LAST
 } AsAppSourceKind;
 
+/**
+ * AsAppKind:
+ * @AS_APP_KIND_UNKNOWN:		Type invalid or not known
+ * @AS_APP_KIND_DESKTOP:		A desktop application
+ * @AS_APP_KIND_FONT:			A font add-on
+ * @AS_APP_KIND_CODEC:			A codec add-on
+ * @AS_APP_KIND_INPUT_METHOD:		A input method add-on
+ * @AS_APP_KIND_WEB_APP:		A web appication
+ * @AS_APP_KIND_SOURCE:			A software source
+ * @AS_APP_KIND_ADDON:			An addon, e.g. a plugin
+ * @AS_APP_KIND_FIRMWARE:		A firmware update
+ * @AS_APP_KIND_RUNTIME:		Runtime platform
+ * @AS_APP_KIND_GENERIC:		Generic component
+ * @AS_APP_KIND_OS_UPDATE:		Operating system update
+ * @AS_APP_KIND_OS_UPGRADE:		Operating system upgrade
+ * @AS_APP_KIND_SHELL_EXTENSION:	GNOME Shell extension
+ * @AS_APP_KIND_LOCALIZATION:		Localization data
+ *
+ * The component type.
+ **/
+typedef enum {
+	AS_APP_KIND_UNKNOWN,		/* Since: 0.5.10 */
+	AS_APP_KIND_DESKTOP,		/* Since: 0.5.10 */
+	AS_APP_KIND_FONT,		/* Since: 0.5.10 */
+	AS_APP_KIND_CODEC,		/* Since: 0.5.10 */
+	AS_APP_KIND_INPUT_METHOD,	/* Since: 0.5.10 */
+	AS_APP_KIND_WEB_APP,		/* Since: 0.5.10 */
+	AS_APP_KIND_SOURCE,		/* Since: 0.5.10 */
+	AS_APP_KIND_ADDON,		/* Since: 0.5.10 */
+	AS_APP_KIND_FIRMWARE,		/* Since: 0.5.10 */
+	AS_APP_KIND_RUNTIME,		/* Since: 0.5.10 */
+	AS_APP_KIND_GENERIC,		/* Since: 0.5.10 */
+	AS_APP_KIND_OS_UPDATE,		/* Since: 0.5.10 */
+	AS_APP_KIND_OS_UPGRADE,		/* Since: 0.5.10 */
+	AS_APP_KIND_SHELL_EXTENSION,	/* Since: 0.5.10 */
+	AS_APP_KIND_LOCALIZATION,	/* Since: 0.5.11 */
+	/*< private >*/
+	AS_APP_KIND_LAST
+} AsAppKind;
+
+/**
+ * AsAppQuirk:
+ * @AS_APP_QUIRK_NONE:			No special attributes
+ * @AS_APP_QUIRK_PROVENANCE:		Installed by OS vendor
+ * @AS_APP_QUIRK_COMPULSORY:		Cannot be removed
+ * @AS_APP_QUIRK_HAS_SOURCE:		Has a source to allow staying up-to-date
+ * @AS_APP_QUIRK_MATCH_ANY_PREFIX:	Matches applications with any prefix
+ *
+ * The component attributes.
+ **/
+typedef enum {
+	AS_APP_QUIRK_NONE		= 0,		/* Since: 0.5.10 */
+	AS_APP_QUIRK_PROVENANCE		= 1 << 0,	/* Since: 0.5.10 */
+	AS_APP_QUIRK_COMPULSORY		= 1 << 1,	/* Since: 0.5.10 */
+	AS_APP_QUIRK_HAS_SOURCE		= 1 << 2,	/* Since: 0.5.10 */
+	AS_APP_QUIRK_MATCH_ANY_PREFIX	= 1 << 3,	/* Since: 0.5.12 */
+	/*< private >*/
+	AS_APP_QUIRK_LAST
+} AsAppQuirk;
+
 /**
  * AsAppState:
  * @AS_APP_STATE_UNKNOWN:			Unknown state
@@ -206,9 +268,11 @@ AsAppSourceKind	 as_app_guess_source_kind	(const gchar	*filename);
 AsAppSourceKind	 as_app_source_kind_from_string	(const gchar	*source_kind);
 const gchar	*as_app_source_kind_to_string	(AsAppSourceKind source_kind);
 const gchar	*as_app_state_to_string		(AsAppState	 state);
+const gchar	*as_app_kind_to_string		(AsAppKind	 kind);
+AsAppKind	 as_app_kind_from_string	(const gchar	*kind);
 
 /* getters */
-AsIdKind	 as_app_get_id_kind		(AsApp		*app);
+AsAppKind	 as_app_get_kind		(AsApp		*app);
 AsAppSourceKind	 as_app_get_source_kind		(AsApp		*app);
 AsAppState	 as_app_get_state		(AsApp		*app);
 AsAppTrustFlags	 as_app_get_trust_flags		(AsApp		*app);
@@ -227,8 +291,10 @@ GPtrArray	*as_app_get_architectures	(AsApp		*app);
 GPtrArray	*as_app_get_releases		(AsApp		*app);
 GPtrArray	*as_app_get_provides		(AsApp		*app);
 GPtrArray	*as_app_get_screenshots		(AsApp		*app);
+GPtrArray	*as_app_get_content_ratings	(AsApp		*app);
 GPtrArray	*as_app_get_icons		(AsApp		*app);
 GPtrArray	*as_app_get_bundles		(AsApp		*app);
+GPtrArray	*as_app_get_translations	(AsApp		*app);
 GHashTable	*as_app_get_names		(AsApp		*app);
 GHashTable	*as_app_get_comments		(AsApp		*app);
 GHashTable	*as_app_get_developer_names	(AsApp		*app);
@@ -239,6 +305,7 @@ GPtrArray	*as_app_get_vetos		(AsApp		*app);
 const gchar	*as_app_get_icon_path		(AsApp		*app);
 const gchar	*as_app_get_id_filename		(AsApp		*app);
 const gchar	*as_app_get_id			(AsApp		*app);
+const gchar	*as_app_get_id_no_prefix	(AsApp		*app);
 const gchar	*as_app_get_pkgname_default	(AsApp		*app);
 const gchar	*as_app_get_source_pkgname	(AsApp		*app);
 const gchar	*as_app_get_origin		(AsApp		*app);
@@ -270,12 +337,16 @@ gboolean	 as_app_has_kudo_kind		(AsApp		*app,
 						 AsKudoKind	 kudo);
 gboolean	 as_app_has_permission		(AsApp		*app,
 						 const gchar	*permission);
+gboolean	 as_app_has_compulsory_for_desktop (AsApp	*app,
+						 const gchar	*permission);
+gboolean	 as_app_has_quirk		(AsApp		*app,
+						 AsAppQuirk	 quirk);
 
 /* setters */
 void		 as_app_set_id			(AsApp		*app,
 						 const gchar	*id);
-void		 as_app_set_id_kind		(AsApp		*app,
-						 AsIdKind	 id_kind);
+void		 as_app_set_kind		(AsApp		*app,
+						 AsAppKind	 kind);
 void		 as_app_set_source_kind		(AsApp		*app,
 						 AsAppSourceKind source_kind);
 void		 as_app_set_state		(AsApp		*app,
@@ -335,10 +406,14 @@ void		 as_app_add_provide		(AsApp		*app,
 						 AsProvide	*provide);
 void		 as_app_add_screenshot		(AsApp		*app,
 						 AsScreenshot	*screenshot);
+void		 as_app_add_content_rating	(AsApp		*app,
+						 AsContentRating *content_rating);
 void		 as_app_add_icon		(AsApp		*app,
 						 AsIcon		*icon);
 void		 as_app_add_bundle		(AsApp		*app,
 						 AsBundle	*bundle);
+void		 as_app_add_translation		(AsApp		*app,
+						 AsTranslation	*translation);
 void		 as_app_add_language		(AsApp		*app,
 						 gint		 percentage,
 						 const gchar	*locale);
@@ -356,6 +431,8 @@ void		 as_app_add_addon		(AsApp		*app,
 						 AsApp		*addon);
 void		 as_app_add_extends		(AsApp		*app,
 						 const gchar	*extends);
+void		 as_app_add_quirk		(AsApp		*app,
+						 AsAppQuirk	 quirk);
 
 /* object methods */
 GPtrArray	*as_app_validate		(AsApp		*app,
@@ -384,6 +461,8 @@ gboolean	 as_app_to_file			(AsApp		*app,
 						 GFile		*file,
 						 GCancellable	*cancellable,
 						 GError		**error);
+AsContentRating	*as_app_get_content_rating	(AsApp		*app,
+						 const gchar 	*kind);
 AsIcon		*as_app_get_icon_default	(AsApp		*app);
 AsIcon		*as_app_get_icon_for_size	(AsApp		*app,
 						 guint		 width,
@@ -396,6 +475,15 @@ gboolean	 as_app_convert_icons		(AsApp		*app,
 						 AsIconKind	 kind,
 						 GError		**error);
 
+/* deprecated */
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+AsIdKind	 as_app_get_id_kind		(AsApp		*app)
+G_DEPRECATED_FOR(as_app_get_kind);
+void		 as_app_set_id_kind		(AsApp		*app,
+						 AsIdKind	 id_kind)
+G_DEPRECATED_FOR(as_app_set_kind);
+G_GNUC_END_IGNORE_DEPRECATIONS
+
 G_END_DECLS
 
 #endif /* __AS_APP_H */
